![Python package](https://github.com/hannabacave/logistic_module/workflows/Python%20package/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/logistic-module/badge/?version=latest&token=7d9ba9ec0c7b5a43e16f65d9ecf440dda61bacf75dbf16db1a936596ba77140f)](https://logistic-module.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/hannabacave/logistic_module/branch/master/graph/badge.svg)](https://codecov.io/gh/hannabacave/logistic_module)

# Logistic_module

Logistic_module is a Python module that allows you to produce videos and widget representing some of the elements connected to the logistic map and the Mandelbroot set.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install logistic_module.

```bash
pip install logistic-module
```

## Documentation

The documentation of this package is available on this website : https://logistic-module.readthedocs.io/en/latest/index.html

## Contributers:

```
Hanna Bacave : hanna.bacave@etu.umontpellier.fr
Cindy Delage : cindy.delage@etu.umontpellier.fr
Yassine Mimouni : yassine.mimouni@etu.umontpellier.fr
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## More details

If you interested by the mathematical side of the logistic map, see : https://www.imo.universite-paris-saclay.fr/~perrin/Conferences/logistiqueDP2.pdf
